#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-list
version:              1.1.4
visibility:           public
id:                   hslua-list-1.1.4-4JdJ3rCIjpwFxKRh67s6B8
key:                  hslua-list-1.1.4-4JdJ3rCIjpwFxKRh67s6B8
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Opinionated, but extensible Lua list type.
description:          List type for Lua, with a Haskell interface.
category:             Foreign
abi:                  5f943e6616965ebe963ed8d93318f033
exposed:              True
exposed-modules:      HsLua.List
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-list-1.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-list-1.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-list-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-list
hs-libraries:         HShslua-list-1.1.4-4JdJ3rCIjpwFxKRh67s6B8
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hslua-core-2.3.2-405I0g7OnWG76r3tUC4rD

haddock-interfaces:   /usr/share/doc/haskell-hslua-list/html/hslua-list.haddock
haddock-html:         /usr/share/doc/haskell-hslua-list/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

